@@ -25,8 +25,6 @@
 #include <gio/gio.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 
-#define NAUTILUS_EMBLEM_NAME_PREFIX "emblem-"
-
 struct _NautilusIconInfo
 {
 	GObject parent;
@@ -61,6 +59,12 @@ nautilus_icon_info_init (NautilusIconInfo *icon)
 	icon->sole_owner = TRUE;
 }
 
+gboolean
+nautilus_icon_info_is_fallback (NautilusIconInfo  *icon)
+{
+  return icon->pixbuf == NULL;
+}
+
 static void
 pixbuf_toggle_notify (gpointer      info,
 		      GObject      *object,
@@ -406,8 +410,23 @@ nautilus_icon_info_lookup (GIcon *icon,
 		gtk_icon_info_free (gtkicon_info);
 
 		return g_object_ref (icon_info);
-	} 
-	return nautilus_icon_info_new_for_pixbuf (NULL);
+	} else {
+                GdkPixbuf *pixbuf;
+                GtkIconInfo *gtk_icon_info;
+
+                gtk_icon_info = gtk_icon_theme_lookup_by_gicon (gtk_icon_theme_get_default (),
+                                                                icon,
+                                                                size,
+                                                                GTK_ICON_LOOKUP_GENERIC_FALLBACK);
+                if (gtk_icon_info != NULL) {
+                        pixbuf = gtk_icon_info_load_icon (gtk_icon_info, NULL);
+                        gtk_icon_info_free (gtk_icon_info);
+                } else {
+                        pixbuf = NULL;
+                }
+
+                return nautilus_icon_info_new_for_pixbuf (pixbuf);
+        }
 }
 
 NautilusIconInfo *
@@ -416,13 +435,28 @@ nautilus_icon_info_lookup_from_name (const char *name,
 {
 	GIcon *icon;
 	NautilusIconInfo *info;
-	
+
 	icon = g_themed_icon_new (name);
 	info = nautilus_icon_info_lookup (icon, size);
 	g_object_unref (icon);
 	return info;
 }
 
+NautilusIconInfo *
+nautilus_icon_info_lookup_from_path (const char *path,
+				     int size)
+{
+	GFile *icon_file;
+	GIcon *icon;
+	NautilusIconInfo *info;
+
+	icon_file = g_file_new_for_path (path);
+	icon = g_file_icon_new (icon_file);
+	info = nautilus_icon_info_lookup (icon, size);
+	g_object_unref (icon);
+	g_object_unref (icon_file);
+	return info;
+}
 
 GdkPixbuf *
 nautilus_icon_info_get_pixbuf_nodefault (NautilusIconInfo  *icon)
@@ -645,16 +679,6 @@ nautilus_get_icon_size_for_stock_size (GtkIconSize size)
 }
 
 
-char *
-nautilus_icon_get_emblem_icon_by_name (const char *emblem_name)
-{
-	char *name_with_prefix;
-
-	name_with_prefix = g_strconcat (NAUTILUS_EMBLEM_NAME_PREFIX, emblem_name, NULL);
-
-	return name_with_prefix;
-}
-
 guint
 nautilus_icon_get_emblem_size_for_icon_size (guint size)
 {
