@@ -28,7 +28,7 @@
 
 G_BEGIN_DECLS
 
-void   nautilus_module_init                    (void);
+void   nautilus_module_setup                   (void);
 GList *nautilus_module_get_extensions_for_type (GType  type);
 void   nautilus_module_extension_list_free     (GList *list);
 
