@@ -127,7 +127,6 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 	GtkWidget *toolbar;
 	NautilusWindow *win;
 	NautilusNavigationWindowPane *pane;
-	NautilusWindowSlot *slot;
 	GtkWidget *hpaned;
 	GtkWidget *vbox;
 
@@ -173,10 +172,6 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 
 	nautilus_navigation_window_initialize_actions (window);
 
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE)) {
-		slot = create_extra_pane (window);
-	}
-
 	nautilus_navigation_window_initialize_menus (window);
 
 	ui_manager = nautilus_window_get_ui_manager (NAUTILUS_WINDOW (window));
@@ -897,7 +892,7 @@ gboolean
 nautilus_navigation_window_toolbar_showing (NautilusNavigationWindow *window)
 {
 	if (window->details->toolbar != NULL) {
-		return GTK_WIDGET_VISIBLE (window->details->toolbar);
+		return gtk_widget_get_visible (window->details->toolbar);
 	}
 	/* If we're not visible yet we haven't changed visibility, so its TRUE */
 	return TRUE;
@@ -931,7 +926,7 @@ gboolean
 nautilus_navigation_window_status_bar_showing (NautilusNavigationWindow *window)
 {
 	if (NAUTILUS_WINDOW (window)->details->statusbar != NULL) {
-		return GTK_WIDGET_VISIBLE (NAUTILUS_WINDOW (window)->details->statusbar);
+		return gtk_widget_get_visible (NAUTILUS_WINDOW (window)->details->statusbar);
 	}
 	/* If we're not visible yet we haven't changed visibility, so its TRUE */
 	return TRUE;
@@ -1284,12 +1279,6 @@ nautilus_navigation_window_split_view_on (NautilusNavigationWindow *window)
 	} else {
 		nautilus_navigation_window_pane_hide_location_bar (pane, TRUE);
 	}
-
-	/* remember in gconf */
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE) &&
-	    !eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE, TRUE);
-	}
 }
 
 void
@@ -1315,11 +1304,6 @@ nautilus_navigation_window_split_view_off (NautilusNavigationWindow *window)
 	}
 
 	nautilus_navigation_window_update_show_hide_menu_items (window);
-	/* remember in gconf */
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE) &&
-	    eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE, FALSE);
-	}
 }
 
 gboolean
