@@ -81,6 +81,11 @@ struct NautilusWindowDetails
          */
         GList *panes;
         NautilusWindowPane *active_pane;
+
+	/* So we can tell which window initiated
+	 * an unmount operation.
+	 */
+	gboolean initiated_unmount;
 };
 
 struct _NautilusNavigationWindowDetails {
